﻿// <copyright company="PEER Group GmbH">
//    Copyright (c) PEER Group GmbH. All rights reserved.
// </copyright>

using System;
using System.Windows;
using Infragistics.Windows.DockManager;
using Microsoft.Practices.Prism.Modularity;
using Microsoft.Practices.Prism.Regions;
using Microsoft.Practices.Prism.UnityExtensions;
using Microsoft.Practices.ServiceLocation;
using Microsoft.Practices.Unity;
using SpreadsheetOwnerErrorSampleV3.Core.Prism;
using SpreadsheetOwnerErrorSampleV3.Modules;

namespace SpreadsheetOwnerErrorSampleV3.Core.Bootstrapper
{
	public class AppBootstrapper : UnityBootstrapper
	{
		protected override DependencyObject CreateShell()
		{
			InitializeModules();
			return ServiceLocator.Current.GetInstance<MainWindow>();
		}

		/// <summary>
		/// Runs the initialization steps to ensure that the shell is ready to be displayed. The shell application
		/// object is created and set as the main window of the application.
		/// </summary>
		protected override void InitializeShell()
		{
			base.InitializeShell();

			//App.Current.MainWindow = (Window)Shell;
			//App.Current.MainWindow.Show();
		}

		/// <summary>
		/// Creates the module catalog of the application.
		/// <remarks>
		/// The module catalog holds the information about the modules which can be used by the application.
		/// </remarks>
		/// </summary>
		/// <returns>Returns the created module catalog.</returns>
		//protected override IModuleCatalog CreateModuleCatalog()
		//{
		//	return new AggregateModuleCatalog();
		//}

		protected override void ConfigureModuleCatalog()
		{
			try
			{
				ModuleCatalog.AddModule(new ModuleInfo()
				{
					ModuleName = OutlookModule.NAME,
					ModuleType = typeof(OutlookModule).AssemblyQualifiedName,
					InitializationMode = InitializationMode.WhenAvailable
				});

				ModuleCatalog.AddModule(new ModuleInfo()
				{
					ModuleName = NavigationModule.NAME,
					ModuleType = typeof(NavigationModule).AssemblyQualifiedName,
					InitializationMode = InitializationMode.WhenAvailable,
				});
			}
			catch (ApplicationException ex)
			{
				ErrorHandler.OnError(ex, "bootstrap");
			}
		}

		/// <summary>
		/// Registers the default region adapter mappings. These mappings are used by region manager to associate the
		/// correct adapters for regions.
		/// </summary>
		/// <returns>Returns the configured region adapter mapping.</returns>
		protected override RegionAdapterMappings ConfigureRegionAdapterMappings()
		{
			// Call base method
			var mappings = base.ConfigureRegionAdapterMappings();
			if (mappings == null)
				return null;

			mappings.RegisterMapping(typeof(TabGroupPane), Container.Resolve<TabGroupPaneRegionAdapter>());

			return mappings;
		}
	}
}
